@@ -6,7 +6,7 @@ use vars qw[$VERSION %utilities];
 use Module::CoreList;
 use Module::CoreList::TieHashDelta;
 
-$VERSION = '5.20150912';
+$VERSION = '5.20150920';
 
 sub utilities {
     my $perl = shift;
@@ -1080,6 +1080,13 @@ my %delta = (
         removed => {
         }
     },
+    5.023003 => {
+        delta_from => 5.023002,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 for my $version (sort { $a <=> $b } keys %delta) {
